@@ -15,7 +15,7 @@ use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use Path::Tiny;
 
-our $VERSION = version->new('0.6.0');
+our $VERSION = version->new('0.6.1');
 
 our %systems;
 
@@ -61,7 +61,7 @@ sub get_systems {
 
         for my $file (@files) {
             my $module = $file;
-            $module =~ s{$dir/}{}xms;
+            $module =~ s{\Q$dir\E/}{}xms;
             $module =~ s{/}{::}gxms;
             $module =~ s{[.]pm$}{}xms;
 
@@ -341,7 +341,7 @@ VCS::Which - Generically interface with version control systems
 
 =head1 VERSION
 
-This documentation refers to VCS::Which version 0.6.0.
+This documentation refers to VCS::Which version 0.6.1.
 
 =head1 SYNOPSIS
 
